package App::collen ;  
our $VERSION = '0.150' ; 
our $DATE = '2023-08-12T15:05+09:00' ; 

=encoding utf8

=head1 NAME

App::collen -- shows the numbers related to the numbers of the columns of each input line.

=head1 SYNOPSIS

This module provides a Unix-like command `F<collen>'. 

=head1 DESCRIPTION

English explnation has not yet been provided. 
Please see the Japanese explanation by `collen --help'. 


=head1 SEE ALSO

=head1 AUTHOR

下野寿之 Toshiyuki SHIMONO <bin4tsv@gmail.com> The Institute of Statistical Mathematics, a visiting researcher. 

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2016-2023 Toshiyuki SHIMONO. All rights reserved.
This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut

1 ;
